@@ -4,12 +4,14 @@ import (
 	"context"
 	"time"
 
+	"k8s.io/client-go/kubernetes"
+
 	"github.com/kris-nova/logger"
-	"github.com/weaveworks/eksctl/pkg/eks"
 	"golang.org/x/sync/errgroup"
 	"golang.org/x/sync/semaphore"
 
 	"github.com/weaveworks/eksctl/pkg/drain"
+	"github.com/weaveworks/eksctl/pkg/eks"
 )
 
 type DrainInput struct {
@@ -23,7 +25,13 @@ type DrainInput struct {
 	Parallel              int
 }
 
-func (m *Manager) Drain(ctx context.Context, input *DrainInput) error {
+// A Drainer drains nodegroups.
+type Drainer struct {
+	ClientSet kubernetes.Interface
+}
+
+// Drain drains nodegroups.
+func (d *Drainer) Drain(ctx context.Context, input *DrainInput) error {
 	parallelLimit := int64(input.Parallel)
 	sem := semaphore.NewWeighted(parallelLimit)
 	logger.Info("starting parallel draining, max in-flight of %d", parallelLimit)
@@ -36,7 +44,7 @@ func (m *Manager) Drain(ctx context.Context, input *DrainInput) error {
 	for _, nodegroup := range input.NodeGroups {
 		nodegroup := nodegroup
 		g.Go(func() error {
-			nodeGroupDrainer := drain.NewNodeGroupDrainer(m.clientSet, nodegroup, input.MaxGracePeriod, input.NodeDrainWaitPeriod, input.PodEvictionWaitPeriod, input.Undo, input.DisableEviction, input.Parallel)
+			nodeGroupDrainer := drain.NewNodeGroupDrainer(d.ClientSet, nodegroup, input.MaxGracePeriod, input.NodeDrainWaitPeriod, input.PodEvictionWaitPeriod, input.Undo, input.DisableEviction, input.Parallel)
 			return nodeGroupDrainer.Drain(ctx, sem)
 		})
 	}
