@@ -6,6 +6,7 @@ import (
 	"encoding/json"
 	"fmt"
 	"os"
+	"time"
 
 	"github.com/kris-nova/logger"
 	"github.com/stretchr/testify/mock"
@@ -40,6 +41,14 @@ type migrateToPodIdentityAssociationEntry struct {
 	expectedErr                string
 }
 
+type addonCreator struct {
+	addonManager *addon.Manager
+}
+
+func (a *addonCreator) Create(ctx context.Context, addon *api.Addon, waitTimeout time.Duration) error {
+	return a.addonManager.Create(ctx, addon, nil, waitTimeout)
+}
+
 var _ = Describe("Create", func() {
 	var (
 		migrator         *podidentityassociation.Migrator
@@ -57,25 +66,6 @@ var _ = Describe("Create", func() {
 		genericErr = fmt.Errorf("ERR")
 	)
 
-	var policyDocument = aws.String(`{
-		"Version": "2012-10-17",
-		"Statement": [
-			{
-				"Effect": "Allow",
-				"Principal": {
-					"Federated": "arn:aws:iam::111122223333:oidc-provider/oidc.eks.us-west-2.amazonaws.com/id/test"
-				},
-				"Action": "sts:AssumeRoleWithWebIdentity",
-				"Condition": {
-					"StringEquals": {
-						"oidc.eks.eu-north-1.amazonaws.com/id/test:sub": "system:serviceaccount:default:service-account-1",
-						"oidc.eks.eu-north-1.amazonaws.com/id/test:aud": "sts.amazonaws.com"
-					}
-				}
-			}
-		]
-	}`)
-
 	mockDescribeAddon := func(provider *mockprovider.MockProvider, err error) {
 		mockProvider.MockEKS().
 			On("DescribeAddon", mock.Anything, mock.Anything).
@@ -104,6 +94,9 @@ var _ = Describe("Create", func() {
 		}
 
 		mockProvider = mockprovider.NewMockProvider()
+		mockProvider.MockEKS().On("ListAddons", mock.Anything, &awseks.ListAddonsInput{
+			ClusterName: aws.String(clusterName),
+		}).Return(&awseks.ListAddonsOutput{}, nil)
 		if e.mockEKS != nil {
 			e.mockEKS(mockProvider)
 		}
@@ -121,7 +114,7 @@ var _ = Describe("Create", func() {
 			logger.Writer = output
 		}
 
-		addonCreator, err := addon.New(api.NewClusterConfig(), mockProvider.MockEKS(), nil, false, nil, nil)
+		addonManager, err := addon.New(api.NewClusterConfig(), mockProvider.MockEKS(), nil, false, nil, nil)
 		Expect(err).NotTo(HaveOccurred())
 
 		migrator = podidentityassociation.NewMigrator(
@@ -130,7 +123,7 @@ var _ = Describe("Create", func() {
 			mockProvider.MockIAM(),
 			fakeStackUpdater,
 			fakeClientset,
-			addonCreator,
+			&addonCreator{addonManager: addonManager},
 		)
 
 		err = migrator.MigrateToPodIdentity(context.Background(), e.options)
@@ -220,8 +213,6 @@ var _ = Describe("Create", func() {
 			validateCustomLoggerOutput: func(output string) {
 				Expect(output).To(ContainSubstring("update trust policy for owned role \"test-role-1\""))
 				Expect(output).To(ContainSubstring("update trust policy for unowned role \"test-role-2\""))
-				Expect(output).To(ContainSubstring("create service account \"default/service-account-1\", if it does not already exist"))
-				Expect(output).To(ContainSubstring("create service account \"default/service-account-2\", if it does not already exist"))
 				Expect(output).To(ContainSubstring("create pod identity association for service account \"default/service-account-1\""))
 				Expect(output).To(ContainSubstring("create pod identity association for service account \"default/service-account-2\""))
 			},
@@ -280,6 +271,9 @@ var _ = Describe("Create", func() {
 					},
 				}, nil)
 
+				stackUpdater.GetStackTemplateReturnsOnCall(0, iamRoleStackTemplate(nsDefault, sa1), nil)
+				stackUpdater.GetStackTemplateReturnsOnCall(1, iamRoleStackTemplate(nsDefault, sa2), nil)
+
 				stackUpdater.MustUpdateStackStub = func(ctx context.Context, options manager.UpdateStackOptions) error {
 					Expect(options.Stack).NotTo(BeNil())
 					Expect(options.Stack.Tags).To(ConsistOf([]cfntypes.Tag{
@@ -289,6 +283,9 @@ var _ = Describe("Create", func() {
 						},
 					}))
 					Expect(options.Stack.Capabilities).To(ConsistOf([]cfntypes.Capability{"CAPABILITY_IAM"}))
+					template := string(options.TemplateData.(manager.TemplateBody))
+					Expect(template).To(ContainSubstring(api.EKSServicePrincipal))
+					Expect(template).NotTo(ContainSubstring("oidc"))
 					return nil
 				}
 			},
@@ -303,3 +300,66 @@ var _ = Describe("Create", func() {
 		}),
 	)
 })
+
+var policyDocument = aws.String(`{
+	"Version": "2012-10-17",
+	"Statement": [
+		{
+			"Effect": "Allow",
+			"Principal": {
+				"Federated": "arn:aws:iam::111122223333:oidc-provider/oidc.eks.us-west-2.amazonaws.com/id/test"
+			},
+			"Action": "sts:AssumeRoleWithWebIdentity",
+			"Condition": {
+				"StringEquals": {
+					"oidc.eks.eu-north-1.amazonaws.com/id/test:sub": "system:serviceaccount:default:service-account-1",
+					"oidc.eks.eu-north-1.amazonaws.com/id/test:aud": "sts.amazonaws.com"
+				}
+			}
+		}
+	]
+}`)
+
+var iamRoleStackTemplate = func(ns, sa string) string {
+	return fmt.Sprintf(`{
+		"AWSTemplateFormatVersion": "2010-09-09",
+		"Description": "IAM role for serviceaccount \"%s/%s\" [created and managed by eksctl]",
+		"Resources": {
+		  "Role1": {
+			"Type": "AWS::IAM::Role",
+			"Properties": {
+			  "AssumeRolePolicyDocument": {
+				"Statement": [
+				  {
+					"Action": [
+					  "sts:AssumeRoleWithWebIdentity"
+					],
+					"Condition": {
+					  "StringEquals": {
+						"oidc.eks.ap-northeast-2.amazonaws.com/id/BD00DB7DD37421596942D195F2B4F419:aud": "sts.amazonaws.com",
+						"oidc.eks.ap-northeast-2.amazonaws.com/id/BD00DB7DD37421596942D195F2B4F419:sub": "system:serviceaccount:backend-apps:s3-reader"
+					  }
+					},
+					"Effect": "Allow",
+					"Principal": {
+					  "Federated": "arn:aws:iam::111122223333:oidc-provider/oidc.eks.ap-northeast-2.amazonaws.com/id/BD00DB7DD37421596942D195F2B4F419"
+					}
+				  }
+				],
+				"Version": "2012-10-17"
+			  },
+			  "ManagedPolicyArns": [
+				"arn:aws:iam::aws:policy/AmazonS3ReadOnlyAccess"
+			  ]
+			}
+		  }
+		},
+		"Outputs": {
+		  "Role1": {
+			"Value": {
+			  "Fn::GetAtt": "Role1.Arn"
+			}
+		  }
+		}
+	  }`, ns, sa)
+}
