@@ -13,7 +13,9 @@ import (
 	"github.com/spf13/pflag"
 
 	"github.com/weaveworks/eksctl/pkg/actions/addon"
+	"github.com/weaveworks/eksctl/pkg/actions/podidentityassociation"
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
+	"github.com/weaveworks/eksctl/pkg/awsapi"
 	"github.com/weaveworks/eksctl/pkg/ctl/cmdutils"
 )
 
@@ -31,6 +33,7 @@ func createAddonCmd(cmd *cmdutils.Cmd) {
 		fs.StringVar(&cmd.ClusterConfig.Addons[0].Name, "name", "", "Add-on name")
 		fs.StringVar(&cmd.ClusterConfig.Addons[0].Version, "version", "", "Add-on version. Use `eksctl utils describe-addon-versions` to discover a version or set to \"latest\"")
 		fs.StringVar(&cmd.ClusterConfig.Addons[0].ServiceAccountRoleARN, "service-account-role-arn", "", "Add-on serviceAccountRoleARN")
+		fs.BoolVar(&cmd.ClusterConfig.AddonsConfig.AutoApplyPodIdentityAssociations, "auto-apply-pod-identity-associations", false, "apply recommended pod identity associations for the addon(s), if supported")
 		fs.BoolVar(&force, "force", false, "Force migrates an existing self-managed add-on to an EKS managed add-on")
 		fs.BoolVar(&wait, "wait", false, "Wait for the addon creation to complete")
 
@@ -67,8 +70,8 @@ func createAddonCmd(cmd *cmdutils.Cmd) {
 			return err
 		}
 
-		if !oidcProviderExists {
-			logger.Warning("no IAM OIDC provider associated with cluster, try 'eksctl utils associate-iam-oidc-provider --region=%s --cluster=%s'", cmd.ClusterConfig.Metadata.Region, cmd.ClusterConfig.Metadata.Name)
+		if err := validatePodIdentityAgentAddon(ctx, clusterProvider.AWSProvider.EKS(), cmd.ClusterConfig); err != nil {
+			return err
 		}
 
 		stackManager := clusterProvider.NewStackManager(cmd.ClusterConfig)
@@ -91,11 +94,32 @@ func createAddonCmd(cmd *cmdutils.Cmd) {
 			return err
 		}
 
+		iamRoleCreator := &podidentityassociation.IAMRoleCreator{
+			ClusterName:  cmd.ClusterConfig.Metadata.Name,
+			StackCreator: stackManager,
+		}
+		// always install EKS Pod Identity Agent Addon first, if present,
+		// as other addons might require IAM permissions
 		for _, a := range cmd.ClusterConfig.Addons {
+			if a.CanonicalName() != api.PodIdentityAgentAddon {
+				continue
+			}
 			if force { //force is specified at cmdline level
 				a.Force = true
 			}
-			if err := addonManager.Create(ctx, a, cmd.ProviderConfig.WaitTimeout); err != nil {
+			if err := addonManager.Create(ctx, a, iamRoleCreator, cmd.ProviderConfig.WaitTimeout); err != nil {
+				return err
+			}
+		}
+
+		for _, a := range cmd.ClusterConfig.Addons {
+			if a.CanonicalName() == api.PodIdentityAgentAddon {
+				continue
+			}
+			if force { //force is specified at cmdline level
+				a.Force = true
+			}
+			if err := addonManager.Create(ctx, a, iamRoleCreator, cmd.ProviderConfig.WaitTimeout); err != nil {
 				return err
 			}
 		}
@@ -103,3 +127,28 @@ func createAddonCmd(cmd *cmdutils.Cmd) {
 		return nil
 	}
 }
+
+func validatePodIdentityAgentAddon(ctx context.Context, eksAPI awsapi.EKS, cfg *api.ClusterConfig) error {
+	isPodIdentityAgentInstalled, err := podidentityassociation.IsPodIdentityAgentInstalled(ctx, eksAPI, cfg.Metadata.Name)
+	if err != nil {
+		return err
+	}
+
+	shallCreatePodIdentityAssociations := cfg.AddonsConfig.AutoApplyPodIdentityAssociations
+	podIdentityAgentFoundInConfig := false
+	for _, a := range cfg.Addons {
+		if a.CanonicalName() == api.PodIdentityAgentAddon {
+			podIdentityAgentFoundInConfig = true
+		}
+		if a.HasPodIDsSet() || a.UseDefaultPodIdentityAssociations {
+			shallCreatePodIdentityAssociations = true
+		}
+	}
+
+	if shallCreatePodIdentityAssociations && !isPodIdentityAgentInstalled && !podIdentityAgentFoundInConfig {
+		suggestion := fmt.Sprintf("please enable it using `eksctl create addon --cluster=%s --name=%s`, or by adding it to the config file", cfg.Metadata.Name, api.PodIdentityAgentAddon)
+		return api.ErrPodIdentityAgentNotInstalled(suggestion)
+	}
+
+	return nil
+}
